/*
 * Copyright 2018 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package app.tivi.interactors

import app.tivi.data.repositories.trendingshows.TrendingShowsRepository
import app.tivi.interactors.UpdateTrendingShows.Params
import app.tivi.util.AppCoroutineDispatchers
import kotlinx.coroutines.CoroutineDispatcher
import javax.inject.Inject

class UpdateTrendingShows @Inject constructor(
    dispatchers: AppCoroutineDispatchers,
    private val trendingShowsRepository: TrendingShowsRepository
) : Interactor<Params> {
    override val dispatcher: CoroutineDispatcher = dispatchers.io

    override suspend fun invoke(params: Params) = when (params.page) {
        Page.NEXT_PAGE -> trendingShowsRepository.loadNextPage()
        Page.REFRESH -> trendingShowsRepository.refresh()
    }

    data class Params(val page: Page)

    enum class Page {
        NEXT_PAGE, REFRESH
    }
}
